[00:39] <Geth> ¦ nqp: MasterDuke17++ created pull request #880: Reduce $?CLASS lookups

[00:39] <Geth> ¦ nqp: review: https://github.com/Raku/nqp/pull/880

[00:42] *** timo left
[00:55] *** kjp left
[01:08] *** kjp joined
[06:20] *** kjp left
[06:20] *** hankache_ left
[06:20] *** djinni` left
[06:20] *** finanalyst left
[06:20] *** apogee_ntv left
[06:20] *** hankache_ joined
[06:20] *** apogee_ntv joined
[06:21] *** kjp joined
[06:21] *** djinni` joined
[06:24] *** kjp left
[06:24] *** ShimmerFairy left
[06:24] *** coleman left
[06:24] *** Pixi left
[06:25] *** ShimmerFairy joined
[06:25] *** kjp joined
[06:25] *** Pixi joined
[06:27] *** finanalyst joined
[06:33] <Geth> ¦ nqp/main: da5e7771dc | MasterDuke17++ (committed using GitHub Web editor) | src/QRegex/Cursor.nqp

[06:33] <Geth> ¦ nqp/main: Reduce $?CLASS lookups (#880)

[06:33] <Geth> ¦ nqp/main: 

[06:33] <Geth> ¦ nqp/main: Looking it up once and putting it in a local decreases the number of

[06:33] <Geth> ¦ nqp/main: times it's looked up via MVM_frame_find_lexical_by_name. Oddly, my

[06:33] <Geth> ¦ nqp/main: example

[06:33] <Geth> ¦ nqp/main: `raku -e 'my %h; my $c = "rakudo/gen/moar/CORE.c.setting".IO; for ^1 { for $c.lines { %h{$0}++ if /^\s+(\d+)/ } }; say "$_.value():$_.key()" for %h.sort(*.value)'`

[06:33] <Geth> ¦ nqp/main: only sees a 2x reduction, when I would expect something like a 5x

[06:33] <Geth> ¦ nqp/main: reduction.

[06:33] <Geth> ¦ nqp/main: review: https://github.com/Raku/nqp/commit/da5e7771dc

[06:42] *** coleman joined
[07:15] <Geth> ¦ rakudo/main: e77aaaef81 | (Elizabeth Mattijsen)++ | tools/templates/NQP_REVISION

[07:15] <Geth> ¦ rakudo/main: Bump NQP to get $?CLASS lookups fix, Masterduke++

[07:15] <Geth> ¦ rakudo/main: review: https://github.com/rakudo/rakudo/commit/e77aaaef81

[08:06] <Geth> ¦ rakudo/lizmat-81: bff083cf6c | (Elizabeth Mattijsen)++ | src/core.c/Any-iterable-methods.rakumod

[08:06] <Geth> ¦ rakudo/lizmat-81: Reduce bytecode size of .are

[08:06] <Geth> ¦ rakudo/lizmat-81: 

[08:06] <Geth> ¦ rakudo/lizmat-81: Remove the return constraint, it's clear from the code that it

[08:06] <Geth> ¦ rakudo/lizmat-81: either returns True or a Failure

[08:06] <Geth> ¦ rakudo/lizmat-81: 

[08:06] <Geth> ¦ rakudo/lizmat-81: Sadly a "target has a :noinline instruction - ins: takeclosure"

[08:07] <Geth> ¦ rakudo/lizmat-81: is still preventing it from being inlined.  Couldn't figure out

[08:07] <Geth> ¦ rakudo/lizmat-81: why.

[08:07] <Geth> ¦ rakudo/lizmat-81: review: https://github.com/rakudo/rakudo/commit/bff083cf6c

[08:07] <Geth> ¦ rakudo: lizmat++ created pull request #6858: Reduce bytecode size of .are

[08:07] <Geth> ¦ rakudo: review: https://github.com/rakudo/rakudo/pull/6858

[09:05] <Geth> ¦ nqp/main: e5e5a905f1 | (Elizabeth Mattijsen)++ | src/QRegex/Cursor.nqp

[09:05] <Geth> ¦ nqp/main: Some more $?CLASS -> $CLASS shortcuts

[09:05] <Geth> ¦ nqp/main: review: https://github.com/Raku/nqp/commit/e5e5a905f1

[09:56] <Geth> ¦ rakudo/lizmat-81: fb90dafeb3 | (Elizabeth Mattijsen)++ | tools/templates/NQP_REVISION

[09:56] <Geth> ¦ rakudo/lizmat-81: Bump NQP for more $?CLASS fixups

[09:56] <Geth> ¦ rakudo/lizmat-81: review: https://github.com/rakudo/rakudo/commit/fb90dafeb3

[09:56] <lizmat> argh

[09:56] <Geth> ¦ rakudo/main: 50379ea28a | (Elizabeth Mattijsen)++ | tools/templates/NQP_REVISION

[09:56] <Geth> ¦ rakudo/main: Bump NQP for more $?CLASS fixups

[09:56] <Geth> ¦ rakudo/main: review: https://github.com/rakudo/rakudo/commit/50379ea28a

[10:54] *** hankache joined
[10:58] *** hankache_ left
[11:41] *** Pixi left
[11:58] *** Pixi joined
[12:06] <ShimmerFairy> lizmat: created that issue on the array constructor arguments on rakudo's bug tracker. If that's not where you expected me to file the bug (say, you were thinking of it as a spec issue instead), just let me know.

[12:07] <lizmat> thanks, https://github.com/rakudo/rakudo/issues/6859 is fine

[12:43] *** hankache left
[12:48] *** hankache joined
[14:54] *** [Coke] left
[16:51] *** [Coke] joined
[18:05] *** samebchase left
[18:33] *** MasterDuke joined
[18:59] *** MasterDuke left
[19:50] <lizmat> bisectable6: class Foo { has @.bar }; say Foo.new(|{:bar([1, 2, 3])})

[19:50] <bisectable6> lizmat, Will bisect the whole range automagically because no endpoints were provided, hang tight

[19:51] <bisectable6> lizmat, ¦6c (105 commits): «Foo.new(bar => [[1, 2, 3],])␤»

[19:51] <bisectable6> lizmat, Nothing to bisect!

[21:05] *** finanalyst left
